
# Format
- You must generate your response using Russian.
- Your Russian should be simple, clear, concise, and logically well structured.
- Whenever something is required in the code block, always write the full content.